import { eventWithTime, listenerHandler } from '@highlight-run/rrweb/dist/types';
import { FirstLoadListeners } from './listeners/first-load-listeners';
import { ConsoleMethods, DebugOptions, FeedbackWidgetOptions, NetworkRecordingOptions, SessionShortcutOptions } from '../../firstload/src/types/client';
import { PushPayloadMutationVariables, Sdk } from './graph/generated/operations';
import 'clientjs';
export declare const HighlightWarning: (context: string, msg: any) => void;
declare class Logger {
    debug: boolean | undefined;
    constructor(debug?: boolean);
    log(...data: any[]): void;
}
export declare type HighlightClassOptions = {
    organizationID: number | string;
    debug?: boolean | DebugOptions;
    backendUrl?: string;
    tracingOrigins?: boolean | (string | RegExp)[];
    disableNetworkRecording?: boolean;
    networkRecording?: boolean | NetworkRecordingOptions;
    disableConsoleRecording?: boolean;
    consoleMethodsToRecord?: ConsoleMethods[];
    enableSegmentIntegration?: boolean;
    enableStrictPrivacy?: boolean;
    enableCanvasRecording?: boolean;
    firstloadVersion?: string;
    environment?: 'development' | 'production' | 'staging' | string;
    appVersion?: string;
    sessionShortcut?: SessionShortcutOptions;
    feedbackWidget?: FeedbackWidgetOptions;
    sessionSecureID: string;
};
/**
 * Subset of HighlightClassOptions that is stored with the session. These fields are stored for debugging purposes.
 */
declare type HighlightClassOptionsInternal = Omit<HighlightClassOptions, 'firstloadVersion'>;
declare type PropertyType = {
    type?: 'track' | 'session';
    source?: Source;
};
declare type Source = 'segment' | undefined;
export declare type SessionData = {
    sessionID: number;
    sessionSecureID: string;
    projectID: number;
    sessionStartTime?: number;
    lastPushTime?: number;
    userIdentifier?: string;
    userObject?: Object;
};
export declare class Highlight {
    options: HighlightClassOptions;
    /** Determines if the client is running on a Highlight property (e.g. frontend). */
    isRunningOnHighlight: boolean;
    /** Verbose project ID that is exposed to users. Legacy users may still be using ints. */
    organizationID: string;
    graphqlSDK: Sdk;
    events: eventWithTime[];
    sessionData: SessionData;
    ready: boolean;
    state: 'NotRecording' | 'Recording';
    /**
     * The number of requests to public graph that have failed in a row.
     */
    numberOfFailedRequests: number;
    logger: Logger;
    enableSegmentIntegration: boolean;
    enableStrictPrivacy: boolean;
    enableCanvasRecording: boolean;
    debugOptions: DebugOptions;
    listeners: listenerHandler[];
    firstloadVersion: string;
    environment: string;
    sessionShortcut: SessionShortcutOptions;
    /** The end-user's app version. This isn't Highlight's version. */
    appVersion: string | undefined;
    _optionsInternal: HighlightClassOptionsInternal;
    _backendUrl: string;
    _recordingStartTime: number;
    _isOnLocalHost: boolean;
    _onToggleFeedbackFormVisibility: () => void;
    _firstLoadListeners: FirstLoadListeners;
    _eventBytesSinceSnapshot: number;
    _lastSnapshotTime: number;
    pushPayloadTimerId: ReturnType<typeof setTimeout> | undefined;
    feedbackWidgetOptions: FeedbackWidgetOptions;
    hasSessionUnloaded: boolean;
    hasPushedData: boolean;
    static create(options: HighlightClassOptions): Highlight;
    constructor(options: HighlightClassOptions, firstLoadListeners?: FirstLoadListeners);
    _reset(): Promise<void>;
    _initMembers(options: HighlightClassOptions): void;
    identify(user_identifier: string, user_object?: {}, source?: Source): Promise<void>;
    _stringifyProperties(properties_object: any, type: 'session' | 'track' | 'user'): any;
    pushCustomError(message: string, payload?: string): Promise<void>;
    consumeCustomError(error: Error, message?: string, payload?: string): Promise<void>;
    addProperties(properties_obj?: {}, typeArg?: PropertyType): Promise<void>;
    initialize(): Promise<void>;
    /**
     * Stops Highlight from recording.
     * @param manual The end user requested to stop recording.
     */
    stopRecording(manual?: boolean): void;
    getCurrentSessionTimestamp(): number;
    /**
     * Returns the current timestamp for the current session.
     */
    getCurrentSessionURLWithTimestamp(): string;
    getCurrentSessionURL(): string | null;
    toggleFeedbackWidgetVisibility(): void;
    addSessionFeedback({ timestamp, verbatim, user_email, user_name, }: {
        verbatim: string;
        timestamp: string;
        user_name?: string;
        user_email?: string;
    }): void;
    _save(): Promise<void>;
    _shouldSendRequest(): boolean;
    /**
     * This proxy should be used instead of rrweb's native addCustomEvent.
     * The proxy makes sure recording has started before emitting a custom event.
     */
    addCustomEvent<T>(tag: string, payload: T): void;
    _sendPayload({ isBeacon, sendFn, }: {
        isBeacon: boolean;
        sendFn: (payload: PushPayloadMutationVariables) => Promise<number>;
    }): Promise<void>;
}
declare global {
    interface Console {
        defaultLog: any;
        defaultError: any;
        defaultWarn: any;
        defaultDebug: any;
    }
}
export {};
